@@ -1,4 +1,4 @@
-# This file is part of CycloneDX Python Lib
+# This file is part of CycloneDX Python Library
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -40,10 +40,11 @@ from sortedcontainers import SortedSet
 
 from .._internal.compare import ComparableTuple as _ComparableTuple
 from ..exception.model import MutuallyExclusivePropertiesException, NoPropertiesProvidedException
-from ..schema.schema import SchemaVersion1Dot4, SchemaVersion1Dot5
+from ..schema.schema import SchemaVersion1Dot4, SchemaVersion1Dot5, SchemaVersion1Dot6
 from ..serialization import BomRefHelper
-from . import OrganizationalContact, OrganizationalEntity, Property, Tool, XsUri
+from . import Property, Tool, XsUri
 from .bom_ref import BomRef
+from .contact import OrganizationalContact, OrganizationalEntity
 from .impact_analysis import (
     ImpactAnalysisAffectedStatus,
     ImpactAnalysisJustification,
@@ -63,8 +64,12 @@ class BomTargetVersionRange:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, version: Optional[str] = None, range: Optional[str] = None,
-                 status: Optional[ImpactAnalysisAffectedStatus] = None) -> None:
+    def __init__(
+        self, *,
+        version: Optional[str] = None,
+        range: Optional[str] = None,
+        status: Optional[ImpactAnalysisAffectedStatus] = None,
+    ) -> None:
         if not version and not range:
             raise NoPropertiesProvidedException(
                 'One of version or range must be provided for BomTargetVersionRange - neither provided.'
@@ -79,6 +84,7 @@ class BomTargetVersionRange:
 
     @property
     @serializable.xml_sequence(1)
+    @serializable.xml_string(serializable.XmlStringSerializationType.NORMALIZED_STRING)
     def version(self) -> Optional[str]:
         """
         A single version of a component or service.
@@ -153,7 +159,11 @@ class BomTarget:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, ref: str, versions: Optional[Iterable[BomTargetVersionRange]] = None) -> None:
+    def __init__(
+        self, *,
+        ref: str,
+        versions: Optional[Iterable[BomTargetVersionRange]] = None,
+    ) -> None:
         self.ref = ref
         self.versions = versions or []  # type:ignore[assignment]
 
@@ -211,10 +221,13 @@ class VulnerabilityAnalysis:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, state: Optional[ImpactAnalysisState] = None,
-                 justification: Optional[ImpactAnalysisJustification] = None,
-                 responses: Optional[Iterable[ImpactAnalysisResponse]] = None,
-                 detail: Optional[str] = None) -> None:
+    def __init__(
+        self, *,
+        state: Optional[ImpactAnalysisState] = None,
+        justification: Optional[ImpactAnalysisJustification] = None,
+        responses: Optional[Iterable[ImpactAnalysisResponse]] = None,
+        detail: Optional[str] = None,
+    ) -> None:
         if not state and not justification and not responses and not detail:
             raise NoPropertiesProvidedException(
                 'At least one of state, justification, responses or detail must be provided for VulnerabilityAnalysis '
@@ -332,12 +345,17 @@ class VulnerabilityAdvisory:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_advisoryType
     """
 
-    def __init__(self, *, url: XsUri, title: Optional[str] = None) -> None:
+    def __init__(
+        self, *,
+        url: XsUri,
+        title: Optional[str] = None,
+    ) -> None:
         self.title = title
         self.url = url
 
     @property
     @serializable.xml_sequence(1)
+    @serializable.xml_string(serializable.XmlStringSerializationType.NORMALIZED_STRING)
     def title(self) -> Optional[str]:
         """
         The title of this advisory.
@@ -392,7 +410,11 @@ class VulnerabilitySource:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilitySourceType
     """
 
-    def __init__(self, *, name: Optional[str] = None, url: Optional[XsUri] = None) -> None:
+    def __init__(
+        self, *,
+        name: Optional[str] = None,
+        url: Optional[XsUri] = None,
+    ) -> None:
         if not name and not url:
             raise NoPropertiesProvidedException(
                 'Either name or url must be provided for a VulnerabilitySource - neither provided'
@@ -402,6 +424,7 @@ class VulnerabilitySource:
 
     @property
     @serializable.xml_sequence(1)
+    @serializable.xml_string(serializable.XmlStringSerializationType.NORMALIZED_STRING)
     def name(self) -> Optional[str]:
         """
         Name of this Source.
@@ -459,7 +482,11 @@ class VulnerabilityReference:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, id: Optional[str] = None, source: Optional[VulnerabilitySource] = None) -> None:
+    def __init__(
+        self, *,
+        id: Optional[str] = None,
+        source: Optional[VulnerabilitySource] = None,
+    ) -> None:
         if not id and not source:
             raise NoPropertiesProvidedException(
                 'Either id or source must be provided for a VulnerabilityReference - neither provided'
@@ -469,6 +496,7 @@ class VulnerabilityReference:
 
     @property
     @serializable.xml_sequence(1)
+    @serializable.xml_string(serializable.XmlStringSerializationType.NORMALIZED_STRING)
     def id(self) -> Optional[str]:
         """
         The identifier that uniquely identifies the vulnerability in the associated Source. For example: CVE-2021-39182.
@@ -605,6 +633,7 @@ class _VulnerabilityScoreSourceSerializationHelper(serializable.helpers.BaseHelp
         VulnerabilityScoreSource.CVSS_V4,
         VulnerabilityScoreSource.SSVC
     }
+    __CASES[SchemaVersion1Dot6] = __CASES[SchemaVersion1Dot5]
 
     @classmethod
     def __normalize(cls, vss: VulnerabilityScoreSource, view: Type[serializable.ViewType]) -> str:
@@ -697,17 +726,20 @@ class VulnerabilityRating:
 
     .. warning::
         As part of implementing support for CycloneDX schema version 1.4, the three score types defined in the schema
-        externsion used prior to 1.4 have been deprecated. The deprecated `score_base` should loosely be equivalent to
+        extension used prior to 1.4 have been deprecated. The deprecated `score_base` should loosely be equivalent to
         the new `score` in 1.4 schema. Both `score_impact` and `score_exploitability` are deprecated and removed as
         they are redundant if you have the vector (the vector allows you to calculate the scores).
     """
 
-    def __init__(self, *,
-                 source: Optional[VulnerabilitySource] = None, score: Optional[Decimal] = None,
-                 severity: Optional[VulnerabilitySeverity] = None,
-                 method: Optional[VulnerabilityScoreSource] = None, vector: Optional[str] = None,
-                 justification: Optional[str] = None
-                 ) -> None:
+    def __init__(
+        self, *,
+        source: Optional[VulnerabilitySource] = None,
+        score: Optional[Decimal] = None,
+        severity: Optional[VulnerabilitySeverity] = None,
+        method: Optional[VulnerabilityScoreSource] = None,
+        vector: Optional[str] = None,
+        justification: Optional[str] = None,
+    ) -> None:
         if not source and not score and not severity and not method and not vector and not justification:
             raise NoPropertiesProvidedException(
                 'At least one property must be provided when creating a VulnerabilityRating - none supplied.'
@@ -775,6 +807,7 @@ class VulnerabilityRating:
 
     @property
     @serializable.xml_sequence(5)
+    @serializable.xml_string(serializable.XmlStringSerializationType.NORMALIZED_STRING)
     def vector(self) -> Optional[str]:
         """
         The textual representation of the metric values used to score the vulnerability - also known as the vector.
@@ -830,8 +863,11 @@ class VulnerabilityCredits:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, organizations: Optional[Iterable[OrganizationalEntity]] = None,
-                 individuals: Optional[Iterable[OrganizationalContact]] = None) -> None:
+    def __init__(
+        self, *,
+        organizations: Optional[Iterable[OrganizationalEntity]] = None,
+        individuals: Optional[Iterable[OrganizationalContact]] = None,
+    ) -> None:
         if not organizations and not individuals:
             raise NoPropertiesProvidedException(
                 'One of `organizations` or `individuals` must be populated - neither were'
@@ -900,19 +936,28 @@ class Vulnerability:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *,
-                 bom_ref: Optional[Union[str, BomRef]] = None, id: Optional[str] = None,
-                 source: Optional[VulnerabilitySource] = None,
-                 references: Optional[Iterable[VulnerabilityReference]] = None,
-                 ratings: Optional[Iterable[VulnerabilityRating]] = None, cwes: Optional[Iterable[int]] = None,
-                 description: Optional[str] = None, detail: Optional[str] = None, recommendation: Optional[str] = None,
-                 advisories: Optional[Iterable[VulnerabilityAdvisory]] = None, created: Optional[datetime] = None,
-                 published: Optional[datetime] = None, updated: Optional[datetime] = None,
-                 credits: Optional[VulnerabilityCredits] = None,
-                 tools: Optional[Iterable[Tool]] = None, analysis: Optional[VulnerabilityAnalysis] = None,
-                 affects: Optional[Iterable[BomTarget]] = None,
-                 properties: Optional[Iterable[Property]] = None
-                 ) -> None:
+    def __init__(
+        self, *,
+        bom_ref: Optional[Union[str, BomRef]] = None,
+        id: Optional[str] = None,
+        source: Optional[VulnerabilitySource] = None,
+        references: Optional[Iterable[VulnerabilityReference]] = None,
+        ratings: Optional[Iterable[VulnerabilityRating]] = None,
+        cwes: Optional[Iterable[int]] = None,
+        description: Optional[str] = None,
+        detail: Optional[str] = None,
+        recommendation: Optional[str] = None,
+        workaround: Optional[str] = None,
+        advisories: Optional[Iterable[VulnerabilityAdvisory]] = None,
+        created: Optional[datetime] = None,
+        published: Optional[datetime] = None,
+        updated: Optional[datetime] = None,
+        credits: Optional[VulnerabilityCredits] = None,
+        tools: Optional[Iterable[Tool]] = None,
+        analysis: Optional[VulnerabilityAnalysis] = None,
+        affects: Optional[Iterable[BomTarget]] = None,
+        properties: Optional[Iterable[Property]] = None,
+    ) -> None:
         if isinstance(bom_ref, BomRef):
             self._bom_ref = bom_ref
         else:
@@ -925,6 +970,7 @@ class Vulnerability:
         self.description = description
         self.detail = detail
         self.recommendation = recommendation
+        self.workaround = workaround
         self.advisories = advisories or []  # type:ignore[assignment]
         self.created = created
         self.published = published
@@ -953,6 +999,7 @@ class Vulnerability:
 
     @property
     @serializable.xml_sequence(1)
+    @serializable.xml_string(serializable.XmlStringSerializationType.NORMALIZED_STRING)
     def id(self) -> Optional[str]:
         """
         The identifier that uniquely identifies the vulnerability. For example: CVE-2021-39182.
@@ -1081,15 +1128,23 @@ class Vulnerability:
     def recommendation(self, recommendation: Optional[str]) -> None:
         self._recommendation = recommendation
 
-    # @property
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.xml_sequence(9)
-    # def workaround(self) -> ...:
-    #     ...  # TODO since CDX 1.5
-    #
-    # @workaround.setter
-    # def workaround(self, ...) -> None:
-    #     ...  # TODO since CDX 1.5
+    @property
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_sequence(9)
+    def workaround(self) -> Optional[str]:
+        """
+        A bypass, usually temporary, of the vulnerability that reduces its likelihood and/or impact.
+        Workarounds often involve changes to configuration or deployments.
+
+        Returns:
+            `str` if set else `None`
+        """
+        return self._workaround
+
+    @workaround.setter
+    def workaround(self, workaround: Optional[str]) -> None:
+        self._workaround = workaround
 
     # @property
     # @serializable.view(SchemaVersion1Dot5)
@@ -1271,8 +1326,8 @@ class Vulnerability:
     def __hash__(self) -> int:
         return hash((
             self.id, self.source, tuple(self.references), tuple(self.ratings), tuple(self.cwes), self.description,
-            self.detail, self.recommendation, tuple(self.advisories), self.created, self.published, self.updated,
-            self.credits, tuple(self.tools), self.analysis, tuple(self.affects), tuple(self.properties)
+            self.detail, self.recommendation, self.workaround, tuple(self.advisories), self.created, self.published,
+            self.updated, self.credits, tuple(self.tools), self.analysis, tuple(self.affects), tuple(self.properties)
         ))
 
     def __repr__(self) -> str:
